==========================
Firebird driver for Python
==========================

This package contains driver that uses new Firebird API introduced in Firebird 3.
It also works ONLY with Python 3.8+.

